#
# spec file for package python-wmctrl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-wmctrl
Version:        0.5
Release:        2.3
Summary:        Python programmatic control of X windows
# Project is in the process of transitioning from Bitbucket to GitHub
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/antocuni/wmctrl
Source:         https://files.pythonhosted.org/packages/source/w/wmctrl/wmctrl-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  openbox
BuildRequires:  python-rpm-macros
BuildRequires:  wmctrl
BuildRequires:  xclock
BuildRequires:  xfontsel
BuildRequires:  xorg-x11-server
BuildRequires:  xvfb-run
Requires:       python-attrs
Requires:       wmctrl
Requires:       xorg-x11-server
BuildArch:      noarch
%python_subpackages

%description
Python tool to programmatically control windows inside X.

%prep
%setup -q -n wmctrl-%{version}

sed -i 's/\(py$\|py\.test\)/pytest/g' test/test_wmctrl.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand #
cat > /tmp/test_script.sh <<EOF
#!/bin/sh
openbox &
sleep 10
wmctrl -l -G -p -x
$python -m pytest -rs -k 'not (test_activate or test_properties or test_Desktop_active)' test/test_wmctrl.py
EOF
chmod +x /tmp/test_script.sh
xvfb-run /tmp/test_script.sh
}

%files %{python_files}
%license LICENSE
%{python_sitelib}/wmctrl.py*
%pycache_only %{python_sitelib}/__pycache__
%{python_sitelib}/wmctrl*/

%changelog
* Wed Dec 11 2024 Andreas Schwab <schwab@suse.de>
- Avoid race condition in test script
* Mon Dec  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5
  * Add missing dependency
  * Remove use of deprecated py.test in tests
  * commit some edits which has been living in my local copy for years
  * Modernized the packaging configuration
  * Added automatic release workflow
  * Added specification on what module to package
  * Bumped up the version
  * Fixed trigger for the publish action
  * Fixed content-type parameter
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
- Update Requires from pyproject.toml
* Thu Jan 26 2023 John Vandenberg <jayvdb@gmail.com>
- Remove use of deprecated py.test in tests.
* Fri Apr 23 2021 John Vandenberg <jayvdb@gmail.com>
- Remove pr_3.patch and LICENSE which were merged upstream
- Deselect two tests that fail
- Update to v0.4
  * See https://github.com/antocuni/wmctrl/compare/v0.3...v0.4
* Thu Oct 29 2020 John Vandenberg <jayvdb@gmail.com>
- Prefix spec and changes filenames with "python-"
* Mon Oct 26 2020 John Vandenberg <jayvdb@gmail.com>
- Add pr_3.patch to fix Python 3
- Activate test suite
- Update URL from Bitbucket to GitHub
- Add LICENSE from new upstream
* Thu Apr 11 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.3
